@@ -15,10 +15,10 @@ my %params = (
 #                pre_proc => ,
 #                pre_proc_return => 1,
 #                pre_proc_dump => 1,
-                post_proc => 'file_lines_contain',
+                post_proc => ['file_lines_contain'],
 #                post_proc_dump => 1,
 #                post_proc_return => 1,
-                engine => new_has(),
+                engine => dumps(),
 #                engine_return => 1,
 #                engine_dump => 1,
 #                core_dump => 1,
@@ -27,29 +27,27 @@ my %params = (
               );
 
 #<des>
-sub new_has {
+sub dumps {
 
     return sub {
 
         my $p = shift;
         my $struct = shift;
 
-        my $file = (keys %$struct)[0];
-
-        my @has = keys %{$struct->{$file}{subs}};
-
-        return \@has;
+        return $struct;
     };
 }
 #</des>
 
-my $des = Devel::Examine::Subs->new(%params);
-my $struct = $des->run(\%params);
-
-print Dumper $struct;
-
-# uncomment below line to inject the code
-# after you're certain the return is correct
-
-#$des->add_functionality(add_functionality => 'engine');
+my $install = 0; # set this to true to install
 
+if ($install){
+    my $des = Devel::Examine::Subs->new;
+    my $ret = $des->add_functionality(add_functionality => 'engine');
+    print "\n$ret\n";
+}
+else {
+    my $des = Devel::Examine::Subs->new(%params);
+    my $struct = $des->run(\%params);
+    print Dumper $struct;
+}
